/* File jmath.h
 *
 * Defines commonly used primitive macros and functions.  Some macros are
 * redefined to make sure we get them right when porting to different
 * platforms.  The functions are declared in file jmath.cpp.  Some of the
 * functions are "safe" functions, intended to be used in embedded systems
 * where error halts are undesirable.  Instead of halting, the functions
 * return reasonable values and keep going.  Function cmod fixes a problem
 * with the library modulo functions, which give incorrect values if one
 * or both arguments are negative.
 *
*/

#ifndef JMATH_H
	#define JMATH_H

// define logicals for convenience
#ifndef FALSE
	#define FALSE 0
#endif

#ifndef TRUE
	#define TRUE 1
#endif

#undef max
#undef min
#undef abs
#undef sign

#define max(x,y)    (((x) > (y)) ? (x) : (y))
#define min(x,y)    (((x) < (y)) ? (x) : (y))
#define abs(x) 	  (((x) < 0  ) ? -(x): (x))
#define sign(x,y)   (((y) < 0  ) ? (-(abs(x))): (abs(x)))

double mod(double x, double y);
double radians(double x);
double degrees(double x);
double ang_360(double x);
double ang_180(double x);
double square_root(double x);
double sqrt(double a);
double sine(double x);
double sin(double x);
double cosine(double x);
double cos(double x);
double tan(double x);
double tangent(double x);
double arcsin(double x);
double asin(double x);
double arccos(double x);
double acos(double x);
double arctan2(double y, double x);
double atan2(double y, double x);
double exponential(double x);
double exp(double x);
double power(double x, int n);

#endif
